@@ -10,7 +10,7 @@ use strict;
 use warnings;
 use Graph::Easy;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub new
 {
@@ -20,6 +20,19 @@ sub new
 	my $graph = Graph::Easy->new();
 	$graph->set_attribute('fill','white'); # otherwise firefox 2 will have a black background when rendered as svg
 	$graph->set_attribute('flow', $args{flow}) if $args{flow};
+	
+	$graph->set_attribute('node', 'font','Arial');
+	$graph->set_attribute('node', 'shape', $args{class_shape}) if $args{class_shape};
+	$graph->set_attribute('edge', 'arrowstyle', $args{arrow_style}) if $args{arrow_style};
+	
+	if ($args{colorize})
+	{
+		$graph->set_attribute('node', 'color','#666666');
+		$graph->set_attribute('node', 'fill','#dfefff');
+		$graph->set_attribute('node', 'bordercolor','#dddddd');
+		$graph->set_attribute('edge', 'color','grey')
+	}
+	
 	return _graph_it(graph => $graph, @_);
 }
 
@@ -44,12 +57,10 @@ sub _graph_it
 					unless ($graph->edge("$class", "$foreign_class")) #this is to prevent duplicated edges.
 					{
 						my ($class_node, $foreign_class_node, $edge) = $graph->add_edge("$class", "$foreign_class");
-						$edge->set_attribute('arrowstyle', $args{arrow_style}) if $args{arrow_style}; 
-						$edge->set_attribute('color','grey') if $args{colorize};
 						
 						if ($args{no_recursion}) # set attributes for foreign classes if no recursion is enabled
 						{
-							_set_node(node => $foreign_class_node, class_name => $class_name, colorize => $args{colorize}, class_shape => $args{class_shape});
+							$foreign_class_node->set_attribute('label', $foreign_class_name);
 						}
 						else
 						{
@@ -80,7 +91,7 @@ sub _graph_it
 			}
 			
 			my $class_node = $graph->add_node("$class"); #add node for classes without any relationships.
-			_set_node(node => $class_node, class_name => $class_name, colorize => $args{colorize}, class_shape => $args{class_shape}) if $class_node;
+			$class_node->set_attribute('label', $class_name);
 			
 			if ($args{show_columns})
 			{
@@ -98,22 +109,6 @@ sub _graph_it
 	return $graph;
 }
 
-sub _set_node
-{
-	my %args = (@_);
-	my $node = $args{node};
-	$node->set_attribute('label', $args{class_name});
-	$node->set_attribute('font','Arial');
-	if ($args{colorize})
-	{
-		$node->set_attribute('color','#666666');
-		$node->set_attribute('fill','#dfefff');
-		$node->set_attribute('bordercolor','#dddddd');
-	}
-	$node->set_attribute('shape', $args{class_shape}) if $args{class_shape};
-}
-	
-
 sub _prettify
 {
 	my %args = (@_);
@@ -141,12 +136,12 @@ sub _show_columns
 			my $column_name = _prettify(name => $column, prettify => $args{prettify});
 			my ($class_node, $column_node, $edge) = $graph->add_edge($args{class}, $args{class}.'-'.$column);
 			$column_node->set_attribute('label', "$column_name");
-			$column_node->set_attribute('font','Arial');
 			$column_node->set_attribute('fontsize','0.9em');
 			$edge->undirected(1);
 			
 			if ($args{colorize})
 			{
+				$column_node->set_attribute('fill','white');
 				$column_node->set_attribute('color','grey');
 				$column_node->set_attribute('bordercolor','#ff6600');
 				$edge->set_attribute('color','grey');
@@ -239,10 +234,6 @@ Defaulted to circle. It is a shortcut to control the shape of all attributes (co
 
 This is an internal API to construct the graph.
 
-=head2 _set_node()
-
-This is an internal API for setting attributes of class nodes.
-
 =head2 _prettify()
 
 This is an internal API to prettify class labels and attribute (column) labels.
